@@ -6,6 +6,7 @@ namespace Icinga\Controllers;
 use Exception;
 use Zend_Controller_Action_Exception;
 use Icinga\Exception\ProgrammingError;
+use Icinga\Exception\Http\HttpNotFoundException;
 use Icinga\Forms\ConfirmRemovalForm;
 use Icinga\Forms\Dashboard\DashletForm;
 use Icinga\Web\Controller\ActionController;
@@ -105,29 +106,22 @@ class DashboardController extends ActionController
         $action = $this;
         $form->setOnSuccess(function (Form $form) use ($dashboard, $action) {
             try {
-                $pane = $dashboard->getPane($form->getValue('pane'));
+                $pane = $dashboard->getPane($form->getValue('org_pane'));
+                $pane->setTitle($form->getValue('pane'));
             } catch (ProgrammingError $e) {
                 $pane = new Dashboard\Pane($form->getValue('pane'));
                 $pane->setUserWidget();
                 $dashboard->addPane($pane);
             }
             try {
-                $dashlet = $pane->getDashlet($form->getValue('dashlet'));
+                $dashlet = $pane->getDashlet($form->getValue('org_dashlet'));
+                $dashlet->setTitle($form->getValue('dashlet'));
                 $dashlet->setUrl($form->getValue('url'));
             } catch (ProgrammingError $e) {
                 $dashlet = new Dashboard\Dashlet($form->getValue('dashlet'), $form->getValue('url'), $pane);
                 $pane->addDashlet($dashlet);
             }
             $dashlet->setUserWidget();
-            // Rename dashlet
-            if ($form->getValue('org_dashlet') && $form->getValue('org_dashlet') !== $dashlet->getTitle()) {
-                $pane->removeDashlet($form->getValue('org_dashlet'));
-            }
-            // Move
-            if ($form->getValue('org_pane') && $form->getValue('org_pane') !== $pane->getTitle()) {
-                $oldPane = $dashboard->getPane($form->getValue('org_pane'));
-                $oldPane->removeDashlet($dashlet->getTitle());
-            }
             $dashboardConfig = $dashboard->getConfig();
             try {
                 $dashboardConfig->saveIni();
@@ -181,7 +175,7 @@ class DashboardController extends ActionController
             try {
                 $dashboardConfig->saveIni();
                 Notification::success(t('Dashlet has been removed from') . ' ' . $pane->getTitle());
-            }  catch (Exception $e) {
+            } catch (Exception $e) {
                 $action->view->error = $e;
                 $action->view->config = $dashboardConfig;
                 $action->render('error');
@@ -197,6 +191,62 @@ class DashboardController extends ActionController
         $this->view->form = $form;
     }
 
+    public function renamePaneAction()
+    {
+        $paneName = $this->params->getRequired('pane');
+        if (! $this->dashboard->hasPane($paneName)) {
+            throw new HttpNotFoundException('Pane not found');
+        }
+
+        $form = new Form();
+        $form->setRedirectUrl('dashboard/settings');
+        $form->setSubmitLabel($this->translate('Update Pane'));
+        $form->addElement(
+            'text',
+            'name',
+            array(
+                'required'  => true,
+                'label'     => $this->translate('Name')
+            )
+        );
+        $form->addElement(
+            'text',
+            'title',
+            array(
+                'required'  => true,
+                'label'     => $this->translate('Title')
+            )
+        );
+        $form->setDefaults(array(
+            'name'  => $paneName,
+            'title' => $this->dashboard->getPane($paneName)->getTitle()
+        ));
+        $form->setOnSuccess(function ($form) use ($paneName) {
+            $newName = $form->getValue('name');
+            $newTitle = $form->getValue('title');
+
+            $pane = $this->dashboard->getPane($paneName);
+            $pane->setName($newName);
+            $pane->setTitle($newTitle);
+            $this->dashboard->getConfig()->saveIni();
+
+            Notification::success(
+                sprintf($this->translate('Pane "%s" successfully renamed to "%s"'), $paneName, $newName)
+            );
+        });
+
+        $form->handleRequest();
+
+        $this->view->form = $form;
+        $this->getTabs()->add(
+            'update-pane',
+            array(
+                'title' => $this->translate('Update Pane'),
+                'url'   => $this->getRequest()->getUrl()
+            )
+        )->activate('update-pane');
+    }
+
     public function removePaneAction()
     {
         $form = new ConfirmRemovalForm();
@@ -212,12 +262,12 @@ class DashboardController extends ActionController
         $action = $this;
         $form->setOnSuccess(function (Form $form) use ($dashboard, $pane, $action) {
             $pane = $dashboard->getPane($pane);
-            $dashboard->removePane($pane->getTitle());
+            $dashboard->removePane($pane->getName());
             $dashboardConfig = $dashboard->getConfig();
             try {
                 $dashboardConfig->saveIni();
                 Notification::success(t('Dashboard has been removed') . ': ' . $pane->getTitle());
-            }  catch (Exception $e) {
+            } catch (Exception $e) {
                 $action->view->error = $e;
                 $action->view->config = $dashboardConfig;
                 $action->render('error');
