@@ -15,7 +15,7 @@ class LimiterControlForm extends Form
      *
      * @var string
      */
-    const CSS_CLASS_LIMITER = 'limiter-control';
+    const CSS_CLASS_LIMITER = 'limiter-control icinga-controls';
 
     /**
      * Default limit
@@ -25,7 +25,7 @@ class LimiterControlForm extends Form
     const DEFAULT_LIMIT = 50;
 
     /**
-     * Selectable limits
+     * Selectable default limits
      *
      * @var int[]
      */
@@ -37,6 +37,11 @@ class LimiterControlForm extends Form
         500 => '500'
     );
 
+    public static $defaultElementDecorators = [
+        ['Label', ['tag' => 'span', 'separator' => '']],
+        ['ViewHelper', ['separator' => '']],
+    ];
+
     /**
      * Default limit for this instance
      *
@@ -71,7 +76,14 @@ class LimiterControlForm extends Form
      */
     public function setDefaultLimit($defaultLimit)
     {
-        $this->defaultLimit = (int) $defaultLimit;
+        $defaultLimit = (int) $defaultLimit;
+
+        if (! isset(static::$limits[$defaultLimit])) {
+            static::$limits[$defaultLimit] = $defaultLimit;
+        }
+
+        $this->defaultLimit = $defaultLimit;
+
         return $this;
     }
 
@@ -90,6 +102,13 @@ class LimiterControlForm extends Form
      */
     public function createElements(array $formData)
     {
+        $options = static::$limits;
+        $pageSize = (int) $this->getRequest()->getUrl()->getParam('limit', $this->getDefaultLimit());
+
+        if (! isset($options[$pageSize])) {
+            $options[$pageSize] = $pageSize;
+        }
+
         $this->addElement(
             'select',
             'limit',
@@ -97,8 +116,8 @@ class LimiterControlForm extends Form
                 'autosubmit'    => true,
                 'escape'        => false,
                 'label'         => '#',
-                'multiOptions'  => static::$limits,
-                'value'         => $this->getRequest()->getUrl()->getParam('limit', $this->getDefaultLimit())
+                'multiOptions'  => $options,
+                'value'         => $pageSize
             )
         );
     }
