@@ -101,6 +101,9 @@ class Cli extends ApplicationBootstrap
         if ($this->params->shift('help')) {
             $this->params->unshift('help');
         }
+        if ($this->params->shift('version')) {
+            $this->params->unshift('version');
+        }
         if ($this->params->shift('autocomplete')) {
             $this->params->unshift('autocomplete');
         }
@@ -146,11 +149,14 @@ class Cli extends ApplicationBootstrap
     {
         $loader = $this->cliLoader();
         $loader->parseParams();
-        $loader->dispatch();
+        $result = $loader->dispatch();
         Benchmark::measure('All done');
         if ($this->showBenchmark) {
             Benchmark::dump();
         }
+        if ($result === false) {
+            exit(3);
+        }
     }
 
     protected function dispatchEndless()
