@@ -6,28 +6,14 @@ namespace Icinga\Authentication\User;
 use Exception;
 use Icinga\Data\Inspectable;
 use Icinga\Data\Inspection;
-use PDO;
 use Icinga\Data\Filter\Filter;
 use Icinga\Exception\AuthenticationException;
 use Icinga\Repository\DbRepository;
 use Icinga\User;
+use PDO;
 
 class DbUserBackend extends DbRepository implements UserBackendInterface, Inspectable
 {
-    /**
-     * The algorithm to use when hashing passwords
-     *
-     * @var string
-     */
-    const HASH_ALGORITHM = '$1$'; // MD5
-
-    /**
-     * The length of the salt to use when hashing a password
-     *
-     * @var int
-     */
-    const SALT_LENGTH = 12; // 12 is required by MD5
-
     /**
      * The query columns being provided
      *
@@ -125,10 +111,12 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
     /**
      * Insert a table row with the given data
      *
-     * @param   string  $table
-     * @param   array   $bind
+     * @param   string $table
+     * @param   array  $bind
+     *
+     * @return void
      */
-    public function insert($table, array $bind)
+    public function insert($table, array $bind, array $types = array())
     {
         $this->requireTable($table);
         $bind['created_at'] = date('Y-m-d H:i:s');
@@ -149,7 +137,7 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
      * @param   array   $bind
      * @param   Filter  $filter
      */
-    public function update($table, array $bind, Filter $filter = null)
+    public function update($table, array $bind, Filter $filter = null, array $types = array())
     {
         $this->requireTable($table);
         $bind['last_modified'] = date('Y-m-d H:i:s');
@@ -177,7 +165,7 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
      */
     protected function persistPassword($value)
     {
-        return $this->hashPassword($value);
+        return password_hash($value, PASSWORD_DEFAULT);
     }
 
     /**
@@ -224,10 +212,10 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
     public function authenticate(User $user, $password)
     {
         try {
-            $passwordHash = $this->getPasswordHash($user->getUsername());
-            $passwordSalt = $this->getSalt($passwordHash);
-            $hashToCompare = $this->hashPassword($password, $passwordSalt);
-            return $hashToCompare === $passwordHash;
+            return password_verify(
+                $password,
+                $this->getPasswordHash($user->getUsername())
+            );
         } catch (Exception $e) {
             throw new AuthenticationException(
                 'Failed to authenticate user "%s" against backend "%s". An exception was thrown:',
@@ -238,43 +226,6 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
         }
     }
 
-    /**
-     * Extract salt from the given password hash
-     *
-     * @param   string  $hash   The hashed password
-     *
-     * @return  string
-     */
-    protected function getSalt($hash)
-    {
-        return substr($hash, strlen(self::HASH_ALGORITHM), self::SALT_LENGTH);
-    }
-
-    /**
-     * Return a random salt
-     *
-     * The returned salt is safe to be used for hashing a user's password
-     *
-     * @return  string
-     */
-    protected function generateSalt()
-    {
-        return openssl_random_pseudo_bytes(self::SALT_LENGTH);
-    }
-
-    /**
-     * Hash a password
-     *
-     * @param   string  $password
-     * @param   string  $salt
-     *
-     * @return  string
-     */
-    protected function hashPassword($password, $salt = null)
-    {
-        return crypt($password, self::HASH_ALGORITHM . ($salt !== null ? $salt : $this->generateSalt()));
-    }
-
     /**
      * Inspect this object to gain extended information about its health
      *
@@ -285,12 +236,7 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
         $insp = new Inspection('Db User Backend');
         $insp->write($this->ds->inspect());
         try {
-            $users = $this->select()->where('is_active', true)->count();
-            if ($users > 0) {
-                $insp->write(sprintf('%s active users', $users));
-            } else {
-                return $insp->error('0 active users', $users);
-            }
+            $insp->write(sprintf('%s active users', $this->select()->where('is_active', true)->count()));
         } catch (Exception $e) {
             $insp->error(sprintf('Query failed: %s', $e->getMessage()));
         }
