@@ -1,9 +1,10 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Data\Db;
 
 use Exception;
+use Zend_Db_Expr;
 use Zend_Db_Select;
 use Icinga\Application\Logger;
 use Icinga\Data\Filter\FilterAnd;
@@ -153,7 +154,10 @@ class DbQuery extends SimpleQuery
             $select->group($group);
         }
 
-        $select->columns($this->columns);
+        if (! empty($this->columns)) {
+            $select->columns($this->columns);
+        }
+
         $this->applyFilterSql($select);
 
         if ($this->hasLimit() || $this->hasOffset()) {
@@ -178,6 +182,9 @@ class DbQuery extends SimpleQuery
         }
     }
 
+    /**
+     * @deprecated  Use DbConnection::renderFilter() instead!
+     */
     protected function renderFilter($filter, $level = 0)
     {
         $str = '';
@@ -291,33 +298,53 @@ class DbQuery extends SimpleQuery
         }
 
         if (is_array($expression)) {
+            $comp = [];
+            $pattern = [];
+            foreach ($expression as $value) {
+                if (strpos($value, '*') === false) {
+                    $comp[] = $value;
+                } else {
+                    $pattern[] = $this->whereToSql($col, $sign, $value);
+                }
+            }
+            $sql = $pattern;
             if ($sign === '=') {
-                return $col . ' IN (' . $this->escapeForSql($expression) . ')';
+                if (! empty($comp)) {
+                    $sql[] = $col . ' IN (' . $this->escapeForSql($comp) . ')';
+                }
+                $operator = 'OR';
             } elseif ($sign === '!=') {
-                return $col . ' NOT IN (' . $this->escapeForSql($expression) . ')';
+                if (! empty($comp)) {
+                    $sql[] = sprintf('(%1$s NOT IN (%2$s) OR %1$s IS NULL)', $col, $this->escapeForSql($comp));
+                }
+                $operator = 'AND';
+            } else {
+                throw new QueryException(
+                    'Unable to render array expressions with operators other than equal or not equal'
+                );
             }
 
-            throw new QueryException('Unable to render array expressions with operators other than equal or not equal');
+            return '(' . implode(" $operator ", $sql) . ')';
         } elseif ($sign === '=' && strpos($expression, '*') !== false) {
             if ($expression === '*') {
-                // We'll ignore such filters as it prevents index usage and because "*" means anything, anything means
-                // all whereas all means that whether we use a filter to match anything or no filter at all makes no
-                // difference, except for performance reasons...
-                return '';
+                return new Zend_Db_Expr('TRUE');
             }
 
             return $col . ' LIKE ' . $this->escapeForSql($this->escapeWildcards($expression));
         } elseif ($sign === '!=' && strpos($expression, '*') !== false) {
             if ($expression === '*') {
-                // We'll ignore such filters as it prevents index usage and because "*" means nothing, so whether we're
-                // using a real column with a valid comparison here or just an expression which cannot be evaluated to
-                // true makes no difference, except for performance reasons...
-                return $this->escapeForSql(0);
+                return new Zend_Db_Expr('FALSE');
             }
 
-            return $col . ' NOT LIKE ' . $this->escapeForSql($this->escapeWildcards($expression));
+            return sprintf(
+                '(%1$s NOT LIKE %2$s OR %1$s IS NULL)',
+                $col,
+                $this->escapeForSql($this->escapeWildcards($expression))
+            );
+        } elseif ($sign === '!=') {
+            return sprintf('(%1$s %2$s %3$s OR %1$s IS NULL)', $col, $sign, $this->escapeForSql($expression));
         } else {
-            return $col . ' ' . $sign . ' ' . $this->escapeForSql($expression);
+            return sprintf('%s %s %s', $col, $sign, $this->escapeForSql($expression));
         }
     }
 
@@ -333,7 +360,9 @@ class DbQuery extends SimpleQuery
         $this->applyFilterSql($count);
         $group = $this->getGroup();
         if ($this->useSubqueryCount || $group) {
-            $count->columns($this->columns);
+            if (! empty($this->columns)) {
+                $count->columns($this->columns);
+            }
             if ($group) {
                 $count->group($group);
             }
@@ -577,4 +606,18 @@ class DbQuery extends SimpleQuery
         $this->select->joinNatural($name, $cols, $schema);
         return $this;
     }
+
+    /**
+     * Add a UNION clause to the query
+     *
+     * @param   array   $select     Select clauses for the union
+     * @param   string  $type       Type of UNION to use
+     *
+     * @return  $this
+     */
+    public function union($select = array(), $type = Zend_Db_Select::SQL_UNION)
+    {
+        $this->select->union($select, $type);
+        return $this;
+    }
 }
