@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2015 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Data\Tree;
 
@@ -84,4 +84,14 @@ class TreeNodeIterator implements RecursiveIterator
     {
         return new static($this->current());
     }
+
+    /**
+     * Get whether the iterator is empty
+     *
+     * @return bool
+     */
+    public function isEmpty()
+    {
+        return ! $this->children->count();
+    }
 }
