@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */
 namespace Icinga\Protocol\File;
 
 use Icinga\Exception\IcingaException;
@@ -7,4 +7,6 @@ use Icinga\Exception\IcingaException;
 /**
  * Exception thrown if a file reader specific error occurs
  */
-class FileReaderException extends IcingaException {}
+class FileReaderException extends IcingaException
+{
+}
