@@ -19,10 +19,24 @@ class ShowController extends Controller
      */
     protected $backend;
 
+    public function init()
+    {
+        $this->view->defaultTitle = $this->translate('Contacts') . ' :: ' . $this->view->defaultTitle;
+
+        parent::init();
+    }
+
     public function contactAction()
     {
         $contactName = $this->params->getRequired('contact_name');
 
+        $this->getTabs()->add('contact-detail', [
+            'title'  => $this->translate('Contact details'),
+            'label'  => $this->translate('Contact'),
+            'url'    => Url::fromRequest(),
+            'active' => true
+        ]);
+
         $query = $this->backend->select()->from('contact', array(
             'contact_name',
             'contact_id',
@@ -56,6 +70,7 @@ class ShowController extends Controller
             $this->view->commands = $commands;
 
             $notifications = $this->backend->select()->from('notification', array(
+                'id',
                 'host_name',
                 'service_description',
                 'notification_output',
@@ -71,6 +86,7 @@ class ShowController extends Controller
             $this->view->notifications = $notifications;
             $this->setupLimitControl();
             $this->setupPaginationControl($this->view->notifications);
+            $this->view->title = $contact->contact_name;
         }
 
         $this->view->contact = $contact;
