@@ -200,10 +200,6 @@ class BackendConfigForm extends ConfigForm
 
         if ($resourceType === null) {
             $resourceType = key($resourceTypes);
-        } elseif ($resourceType === 'livestatus') {
-            throw new ConfigurationError(
-                'We\'ve disabled livestatus support for now because it\'s not feature complete yet'
-            );
         }
 
         $this->addElement(
@@ -220,8 +216,6 @@ class BackendConfigForm extends ConfigForm
             )
         );
 
-        $decorators = static::$defaultElementDecorators;
-        array_pop($decorators); // Removes the HtmlTag decorator
         $this->addElement(
             'select',
             'resource',
@@ -231,7 +225,6 @@ class BackendConfigForm extends ConfigForm
                 'description'   => $this->translate('The resource to use'),
                 'multiOptions'  => $this->resources[$resourceType],
                 'value'         => current($this->resources[$resourceType]),
-                'decorators'    => $decorators,
                 'autosubmit'    => true
             )
         );
@@ -241,7 +234,6 @@ class BackendConfigForm extends ConfigForm
             'resource_note',
             array(
                 'escape'        => false,
-                'decorators'    => $decorators,
                 'value'         => sprintf(
                     '<a href="%1$s" data-base-target="_next" title="%2$s" aria-label="%2$s">%3$s</a>',
                     $this->getView()->url('config/editresource', array('resource' => $resourceName)),
@@ -250,16 +242,6 @@ class BackendConfigForm extends ConfigForm
                 )
             )
         );
-        $this->addDisplayGroup(
-            array('resource', 'resource_note'),
-            'resource-group',
-            array(
-                'decorators'    => array(
-                    'FormElements',
-                    array('HtmlTag', array('tag' => 'div', 'class' => 'control-group'))
-                )
-            )
-        );
 
         if (isset($formData['skip_validation']) && $formData['skip_validation']) {
             // In case another error occured and the checkbox was displayed before
