@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Module\Monitoring\Command\Object;
 
@@ -17,6 +17,15 @@ class DeleteDowntimeCommand extends IcingaCommand
      */
     protected $downtimeId;
 
+    /**
+     * Name of the downtime (Icinga 2.4+)
+     *
+     * Required for removing the downtime via Icinga 2's API.
+     *
+     * @var string
+     */
+    protected $downtimeName;
+
     /**
      * Whether the command affects a service downtime
      *
@@ -47,6 +56,33 @@ class DeleteDowntimeCommand extends IcingaCommand
         return $this;
     }
 
+    /**
+     * Get the name of the downtime (Icinga 2.4+)
+     *
+     * Required for removing the downtime via Icinga 2's API.
+     *
+     * @return string
+     */
+    public function getDowntimeName()
+    {
+        return $this->downtimeName;
+    }
+
+    /**
+     * Set the name of the downtime (Icinga 2.4+)
+     *
+     * Required for removing the downtime via Icinga 2's API.
+     *
+     * @param   string  $downtimeName
+     *
+     * @return  $this
+     */
+    public function setDowntimeName($downtimeName)
+    {
+        $this->downtimeName = $downtimeName;
+        return $this;
+    }
+
     /**
      * Get whether the command affects a service
      *
