@@ -178,7 +178,7 @@ abstract class MonitoredObject implements Filterable
      *
      * @return array All note urls as a string
      */
-    public abstract function getNotesUrls();
+    abstract public function getNotesUrls();
 
     /**
      * {@inheritdoc}
@@ -315,11 +315,6 @@ abstract class MonitoredObject implements Filterable
      */
     public function fetchComments()
     {
-        if ($this->backend->is('livestatus')) {
-            $this->comments = array();
-            return $this;
-        }
-
         $commentsView = $this->backend->select()->from('comment', array(
             'author'            => 'comment_author_name',
             'comment'           => 'comment_data',
@@ -377,11 +372,6 @@ abstract class MonitoredObject implements Filterable
      */
     public function fetchContactgroups()
     {
-        if ($this->backend->is('livestatus')) {
-            $this->contactgroups = array();
-            return $this;
-        }
-
         $contactsGroups = $this->backend->select()->from('contactgroup', array(
             'contactgroup_name',
             'contactgroup_alias'
@@ -404,12 +394,7 @@ abstract class MonitoredObject implements Filterable
      */
     public function fetchContacts()
     {
-        if ($this->backend->is('livestatus')) {
-            $this->contacts = array();
-            return $this;
-        }
-
-        $contacts = $this->backend->select()->from('contact', array(
+        $contacts = $this->backend->select()->from("{$this->type}contact", array(
             'contact_name',
             'contact_alias',
             'contact_email',
@@ -433,11 +418,6 @@ abstract class MonitoredObject implements Filterable
      */
     public function fetchCustomvars()
     {
-        if ($this->backend->is('livestatus')) {
-            $this->customvars = array();
-            return $this;
-        }
-
         $blacklist = array();
         $blacklistPattern = '';
 
@@ -623,6 +603,7 @@ abstract class MonitoredObject implements Filterable
             ->from(
                 'eventhistory',
                 array(
+                    'id',
                     'object_type',
                     'host_name',
                     'host_display_name',
@@ -871,13 +852,17 @@ abstract class MonitoredObject implements Filterable
                     $this->fetchContacts();
                 }
 
-                return array_map(function ($el) { return $el->contact_name; }, $this->contacts);
+                return array_map(function ($el) {
+                    return $el->contact_name;
+                }, $this->contacts);
             } elseif ($name === 'contactgroup_name') {
                 if ($this->contactgroups === null) {
                     $this->fetchContactgroups();
                 }
 
-                return array_map(function ($el) { return $el->contactgroup_name; }, $this->contactgroups);
+                return array_map(function ($el) {
+                    return $el->contactgroup_name;
+                }, $this->contactgroups);
             } elseif ($name === 'hostgroup_name') {
                 if ($this->hostgroups === null) {
                     $this->fetchHostgroups();
