@@ -375,9 +375,13 @@
     ActionTable.prototype.onRowClicked = function (event) {
         var _this = event.data.self;
         var $target = $(event.target);
-        var $tr = $target.closest('tr');
+        var $tr = $(event.currentTarget);
         var table = new Selection($tr.closest('table.action, table.table-row-selectable')[0], _this.icinga);
 
+        if ($tr.closest('[data-no-icinga-ajax]').length > 0) {
+            return true;
+        }
+
         // some rows may contain form actions that trigger a different action, pass those through
         if (!$target.hasClass('rowaction') && $target.closest('form').length &&
             ($target.closest('a').length ||                                         // allow regular link clinks
@@ -407,19 +411,15 @@
             table.select($tr);
         }
 
-        // update history
-        var state = icinga.history.getCol1State();
         var count = table.selections().length;
         if (count > 0) {
             var query = table.toQuery();
             _this.icinga.loader.loadUrl(query, _this.icinga.events.getLinkTargetFor($tr));
-            state += '#!' + query;
         } else {
             if (_this.icinga.events.getLinkTargetFor($tr).attr('id') === 'col2') {
                 _this.icinga.ui.layout1col();
             }
         }
-        _this.icinga.history.pushUrl(state);
 
         // redraw all table selections
         _this.tables().each(function () {
@@ -427,7 +427,7 @@
         });
 
         // update selection info
-        $('.selection-info-count').text(table.selections().size());
+        $('.selection-info-count').text(table.selections().length);
         return false;
     };
 
@@ -470,7 +470,7 @@
 
         // update displayed selection counter
         var table = new Selection(_this.tables(container).first());
-        $(container).find('.selection-info-count').text(table.selections().size());
+        $(container).find('.selection-info-count').text(table.selections().length);
     };
 
     ActionTable.prototype.beforeRender = function(evt) {
