@@ -13,6 +13,7 @@
         this.icinga = icinga;
 
         this.searchValue = '';
+        this.searchTimer = null;
         this.initializeModules = true;
     };
 
@@ -105,6 +106,8 @@
             // Note: It is important that this is the first handler for this event!
             $(document).on('rendered', { self: this }, this.applyHandlers);
 
+            $(document).on('visibilitychange', { self: this }, this.onVisibilityChange);
+
             $.each(this.icinga.behaviors, function (name, behavior) {
                 behavior.bind($(document));
             });
@@ -119,9 +122,6 @@
             $( window ).on('unload', { self: this }, this.onUnload);
             $( window ).on('beforeunload', { self: this }, this.onUnload);
 
-            // We catch scroll events in our containers
-            $('.container').on('scroll', { self: this }, this.icinga.events.onContainerScroll);
-
             // Remove notifications on click
             $(document).on('click', '#notifications li', function () { $(this).remove(); });
 
@@ -145,6 +145,8 @@
 
             $(document).on('click', '.tree .handle', { self: this }, this.treeNodeToggle);
 
+            $(document).on('click', '#search + .search-reset', this.clearSearch);
+
             // TBD: a global autocompletion handler
             // $(document).on('keyup', 'form.auto input', this.formChangeDelayed);
             // $(document).on('change', 'form.auto input', this.formChanged);
@@ -159,6 +161,8 @@
             } else {
                 $parent.addClass('collapsed');
             }
+
+            icinga.ui.fixControls($parent.closest('.container'));
         },
 
         onLoad: function (event) {
@@ -172,12 +176,16 @@
             icinga.destroy();
         },
 
-        /**
-         * A scroll event happened in one of our containers
-         */
-        onContainerScroll: function (event) {
-            // Ugly. And PLEASE, not so often
-            icinga.ui.fixControls();
+        onVisibilityChange: function (event) {
+            var icinga = event.data.self.icinga;
+
+            if (document.visibilityState === undefined || document.visibilityState === 'visible') {
+                icinga.loader.autorefreshSuspended = false;
+                icinga.logger.debug('Page visible, enabling auto-refresh');
+            } else {
+                icinga.loader.autorefreshSuspended = true;
+                icinga.logger.debug('Page invisible, disabling auto-refresh');
+            }
         },
 
         autoCheckRadioButton: function (event) {
@@ -195,7 +203,16 @@
                 return;
             }
             _this.searchValue = $('#menu input.search').val();
-            return _this.autoSubmitForm(event);
+
+            if (_this.searchTimer !== null) {
+                clearTimeout(_this.searchTimer);
+                _this.searchTimer = null;
+            }
+            var _event = $.extend({}, event);  // event seems gc'd once the timeout is over
+            _this.searchTimer = setTimeout(function () {
+                _this.submitForm(_event, true);
+                _this.searchTimer = null;
+            }, 500);
         },
 
         rememberSubmitButton: function(e) {
@@ -232,6 +249,10 @@
                 $form.removeData('submitButton');
             }
 
+            if ($form.closest('[data-no-icinga-ajax]').length > 0) {
+                return true;
+            }
+
             if ($button.length === 0) {
                 var $el;
 
@@ -301,33 +322,6 @@
                 url = icinga.utils.addUrlParams(url, dataObj);
             } else {
                 if (encoding === 'multipart/form-data') {
-                    if (typeof window.FormData === 'undefined') {
-                        icinga.loader.submitFormToIframe($form, url, $target);
-
-                        // Disable all form controls to prevent resubmission as early as possible.
-                        // (This relies on native form submission, so using setTimeout is the only possible solution)
-                        setTimeout(function () {
-                            if ($target.attr('id') == $form.closest('.container').attr('id')) {
-                                $form.find(':input:not(:disabled)').prop('disabled', true);
-                            }
-                        }, 0);
-
-                        if (autosubmit) {
-                            if ($button.length) {
-                                // We're autosubmitting the form so the button has not been clicked, however,
-                                // to be really safe, we're disabling the button explicitly, just in case..
-                                $button.prop('disabled', true);
-                            }
-
-                            $form[0].submit(); // This should actually not trigger the onSubmit event, let's hope that this is true for all browsers..
-                            event.stopPropagation();
-                            event.preventDefault();
-                            return false;
-                        } else {
-                            return true;
-                        }
-                    }
-
                     data = new window.FormData($form[0]);
                 } else {
                     data = $form.serializeArray();
@@ -349,13 +343,13 @@
 
             // Disable all form controls to prevent resubmission except for our search input
             // Note that disabled form inputs will not be enabled via JavaScript again
-            if ($target.attr('id') == $form.closest('.container').attr('id')) {
+            if ($target.attr('id') === $form.closest('.container').attr('id')) {
                 $form.find(':input:not(#search):not(:disabled)').prop('disabled', true);
             }
 
             // Show a spinner depending on how the form is being submitted
-            if (autosubmit && typeof $el !== 'undefined' && $el.next().hasClass('spinner')) {
-                $el.next().addClass('active');
+            if (autosubmit && typeof $el !== 'undefined' && $el.siblings('.spinner').length) {
+                $el.siblings('.spinner').first().addClass('active');
             } else if ($button.length && $button.is('button') && $button.hasClass('animated')) {
                 $button.addClass('active');
             } else if ($button.length && $button.attr('data-progress-label')) {
@@ -440,10 +434,20 @@
                 return true;
             }
 
+            if ($a.closest('[data-no-icinga-ajax]').length > 0) {
+                return true;
+            }
+
+            // Check for ctrl or cmd click to open new tab unless clicking on a multiselect row
+            if ((event.ctrlKey || event.metaKey) && href !== '#' && $a.is('a')) {
+                window.open(href, linkTarget);
+                return false;
+            }
+
             // Special checks for link clicks in action tables
             if (! $a.is('tr[href]') && $a.closest('table.action').length > 0) {
 
-                // ignoray clicks to ANY link with special key pressed
+                // ignore clicks to ANY link with special key pressed
                 if ($a.closest('table.multiselect').length > 0 && (event.ctrlKey || event.metaKey || event.shiftKey)) {
                     return true;
                 }
@@ -595,6 +599,10 @@
             return $target;
         },
 
+        clearSearch: function (event) {
+            $(event.target).parent().find('#search').attr('value', '');
+        },
+
         unbindGlobalHandlers: function () {
             $.each(this.icinga.behaviors, function (name, behavior) {
                 behavior.unbind($(document));
@@ -610,6 +618,7 @@
             $(document).off('change', 'form input.autosubmit', this.submitForm);
             $(document).off('focus', 'form select[data-related-radiobtn]', this.autoCheckRadioButton);
             $(document).off('focus', 'form input[data-related-radiobtn]', this.autoCheckRadioButton);
+            $(document).off('visibilitychange', this.onVisibilityChange);
         },
 
         destroy: function() {
