@@ -154,25 +154,29 @@
          * @param   {object}    [$container]    The container containing the element
          */
         focusElement: function(element, $container) {
-            var $element = $('#' + element);
+            var $element = element;
 
-            if (! $element.length) {
-                // The name attribute is actually deprecated, on anchor tags,
-                // but we'll possibly handle links from another source
-                // (module etc) so that's used as a fallback
-                if ($container && $container.length) {
-                    $element = $container.find('[name="' + element.replace(/'/, '\\\'') + '"]');
-                } else {
-                    $element = $('[name="' + element.replace(/'/, '\\\'') + '"]');
+            if (typeof element === 'string') {
+                $element = $('#' + element);
+
+                if (! $element.length) {
+                    // The name attribute is actually deprecated, on anchor tags,
+                    // but we'll possibly handle links from another source
+                    // (module etc) so that's used as a fallback
+                    if ($container && $container.length) {
+                        $element = $container.find('[name="' + element.replace(/'/, '\\\'') + '"]');
+                    } else {
+                        $element = $('[name="' + element.replace(/'/, '\\\'') + '"]');
+                    }
                 }
             }
 
             if ($element.length) {
-                if (typeof $element.attr('tabindex') === 'undefined') {
+                if (! this.isFocusable($element)) {
                     $element.attr('tabindex', -1);
                 }
 
-                $element.focus();
+                $element[0].focus();
 
                 if ($container && $container.length) {
                     $container.scrollTop(0);
@@ -181,6 +185,12 @@
             }
         },
 
+        isFocusable: function ($element) {
+            return $element.is('*[tabindex], a[href], input:not([disabled]), button:not([disabled])' +
+                ', select:not([disabled]), textarea:not([disabled]), iframe, area[href], object' +
+                ', embed, *[contenteditable]');
+        },
+
         moveToLeft: function () {
             var col2 = this.cutContainer($('#col2'));
             var kill = this.cutContainer($('#col1'));
@@ -268,6 +278,9 @@
                     this.currentLayout = matched[1];
                     if (this.currentLayout === 'poor' || this.currentLayout === 'minimal') {
                         this.layout1col();
+                    } else {
+                        // layout1col() also triggers this, that's why an else is required
+                        $('#layout').trigger('layout-change');
                     }
                     return true;
                 }
@@ -293,6 +306,7 @@
             this.icinga.logger.debug('Switching to single col');
             $('#layout').removeClass('twocols');
             this.closeContainer($('#col2'));
+            $('#layout').trigger('layout-change');
             // one-column layouts never have any selection active
             $('#col1').removeData('icinga-actiontable-former-href');
             this.icinga.behaviors.actiontable.clearAll();
@@ -315,6 +329,7 @@
             this.icinga.logger.debug('Switching to double col');
             $('#layout').addClass('twocols');
             this.fixControls();
+            $('#layout').trigger('layout-change');
         },
 
         getAvailableColumnSpace: function () {
@@ -492,7 +507,7 @@
                 $target.contents().filter(function() { return this.nodeType === 3; }).remove();
 
                 // has three states?
-                var triState = $target.find('input[value="unchanged"]').size() > 0 ? 1 : 0;
+                var triState = $target.find('input[value="unchanged"]').length > 0 ? 1 : 0;
 
                 // fetch current value from radiobuttons
                 var value  = $target.find('input:checked').first().val();
@@ -561,7 +576,7 @@
             var $search = $('#search');
             if (e.which === 13 && $search.is(':focus')) {
                 $('#sidebar').removeClass('expanded');
-                $search.blur();
+                $search[0].blur();
             }
         },
 
@@ -629,8 +644,10 @@
                                 this.toggleMobileMenu
                             )
                             .prepend(
-                                $('<div id="mobile-menu-toggle"><button><i class="icon-menu"></i></button></div>')
+                                $('<div id="mobile-menu-toggle"><button><i class="icon-menu"></i><i class="icon-cancel"></i></button></div>')
                             );
+                            $('#header-logo').clone().attr('id', 'mobile-menu-logo')
+                                .appendTo('#mobile-menu-toggle');
                         $(window).on('keypress', this.closeMobileMenu);
 
                         this.mobileMenu = true;
