@@ -275,9 +275,14 @@ inkey' => 'blarg'
         );
 
         $rendered = $writer->render();
+        $this->assertRegExp(
+            '~linebreak\\\\nin line~',
+            $rendered,
+            'newlines in values are not escaped'
+        );
         $this->assertEquals(
+            4,
             count(explode("\n", $rendered)),
-            5,
             'generated config should not contain more than three line breaks'
         );
     }
@@ -285,9 +290,6 @@ inkey' => 'blarg'
     public function testSectionNameEscaping()
     {
         $config = <<<'EOD'
-[section [brackets\]]
-foo = "bar"
-
 [section \;comment]
 foo = "bar"
 
@@ -304,7 +306,6 @@ EOD;
         $writer = new IniWriter(
             Config::fromArray(
                 array(
-                    'section [brackets]' => array('foo' => 'bar'),
                     'section ;comment' => array('foo' => 'bar'),
                     'section "quotes"' => array('foo' => 'bar'),
                     'section with \\' => array('foo' => 'bar'),
@@ -321,6 +322,15 @@ EOD;
         );
     }
 
+    /**
+     * @expectedException \Icinga\Exception\ConfigurationError
+     */
+    public function testWhetherBracketsAreIllegalInSectionNames()
+    {
+        $config = Config::fromArray(['section [brackets]' => []]);
+        (new IniWriter($config, $this->tempFile))->write();
+    }
+
     public function testDirectiveValueEscaping()
     {
         $config = <<<'EOD'
